@@ -123,6 +123,10 @@ class TemplateSync:
         if self.repo.is_dirty(untracked_files=True):
             print('[bold red]Uncommitted changes found in Project directory!\nPlease commit these before running cookietemple sync')
             sys.exit(1)
+        # Check, whether a cookietemple sync PR is already open
+        elif self.check_pull_request_exists():
+            print('[bold blue]Open cookietemple sync PR still unmerged! No sync will happen until this PR is merged!')
+            sys.exit(0)
 
     def checkout_template_branch(self):
         """
@@ -286,8 +290,6 @@ class TemplateSync:
         log.debug(f'PR title is:\n{pr_title}')
         log.debug(f'PR body is:\n{pr_body_text}')
 
-        # Check, whether a cookietemple sync PR is already open
-        self.check_pull_request_exists()
         # Submit the new pull request with the latest cookietemple sync changes
         self.submit_pull_request(pr_title, pr_body_text)
 
@@ -308,20 +310,18 @@ class TemplateSync:
 
     def check_pull_request_exists(self) -> bool:
         """
-        Check, whether a cookietemple sync PR is already open. If so, close this one, as it is outdated.
+        Check, whether a cookietemple sync PR is already open.
 
         :return Whether a cookietemple sync PR is already open or not
         """
         repo = self.github.get_repo(f'{self.repo_owner}/{self.dot_cookietemple["project_slug"]}')
         # query all open PRs
         log.debug('Querying open PRs to check if a sync PR already exists.')
-        # iterate over the open PRs of the repo to check if a cookietemple sync PR is open
+        # iterate over the open PRs of the repo to check whether a cookietemple sync PR is still open
         for pull_request in repo.get_pulls(state='open'):
-            log.debug('Already open sync PR has been found.')
             # if an older, outdated cookietemple sync PR is still open, close it first
             if 'Important cookietemple template update' in pull_request.title:
-                print('[bold blue]Detected open, but outdated cookietemple sync PR. Closing it in favor of the newest sync PR!')
-                pull_request.edit(state='closed')
+                log.debug('Already open sync PR has been found.')
                 return True
         return False
 
